==> babel-plugin-house-1.0.3.tgz: package/src/index.js <==
const babel = require('babel-core');
const t = require('babel-types');

const visitor = {
  FunctionDeclaration(path) {
    const node = path.node;
    if (t.isIdentifier(path.node.id) && node.id.name === 'executeAction') {
      if (t.isBlockStatement(node.body)) {
        for (let item of node.body.body) {
          if (t.isExpressionStatement(item) && t.isCallExpression(item.expression)) {
            if (t.isIdentifier(item.expression.callee) && item.expression.callee.name === 'endAction') {
              let args = item.expression.arguments;
              args.unshift(t.identifier('actionName'));
              break;
            }
            // console.log(item);
          }
        }
      }
    }
    if (t.isIdentifier(path.node.id) && node.id.name === 'endAction') {
      t.params.unshift(t.identifier('actionName'));
      if (t.isBlockStatement(node.body)) {
        for (let item of node.body.body) {
          if (t.isExpressionStatement(item) && t.isCallExpression(item.expression)) {
            if (t.isIdentifier(item.expression.callee) && item.expression.callee.name === 'spyReportEnd') {
              console.log(item.expression);
              for (let arg of item.expression.arguments) {
                if (t.isObjectExpression(arg)) {
                  const attr = t.objectProperty(t.identifier('actionName'), t.identifier('actionName'));
                  arg.properties.unshift(attr);
                }
              }
            }
          }
        }
      }
    }
  },
  VariableDeclaration(path) {
    const node = path.node;

    if (node.kind === 'let' || node.kind === 'const') {
      // 变量声明的kind, 可以是var let const
      // 然后第二个参数是声明的变量，let a, b, c这里的a, b, c就是node.declarations
      const varNode = t.variableDeclaration('var', node.declarations);
      path.replaceWith(varNode);
    }
  },
  Literal(path) {
    const node = path.node;
    if (node.value === 'hahaha') {
      node.value = 'hahahakakaka';
    }
  }
};
module.exports = function() {
  // 名称必须是visitor
  return { visitor };
};

==> babel-plugin-house-1.0.4.tgz: package/src/index.js <==
const babel = require('babel-core');
const t = require('babel-types');

const visitor = {
  FunctionDeclaration(path) {
    const node = path.node;
    if (t.isIdentifier(path.node.id) && node.id.name === 'executeAction') {
      if (t.isBlockStatement(node.body)) {
        for (let item of node.body.body) {
          if (t.isExpressionStatement(item) && t.isCallExpression(item.expression)) {
            if (t.isIdentifier(item.expression.callee) && item.expression.callee.name === 'endAction') {
              let args = item.expression.arguments;
              args.unshift(t.identifier('actionName'));
              break;
            }
            // console.log(item);
          }
        }
      }
    }
    if (t.isIdentifier(path.node.id) && node.id.name === 'endAction') {
      node.params.unshift(t.identifier('actionName'));
      if (t.isBlockStatement(node.body)) {
        for (let item of node.body.body) {
          if (t.isExpressionStatement(item) && t.isCallExpression(item.expression)) {
            if (t.isIdentifier(item.expression.callee) && item.expression.callee.name === 'spyReportEnd') {
              console.log(item.expression);
              for (let arg of item.expression.arguments) {
                if (t.isObjectExpression(arg)) {
                  const attr = t.objectProperty(t.identifier('actionName'), t.identifier('actionName'));
                  arg.properties.unshift(attr);
                }
              }
            }
          }
        }
      }
    }
  },
  VariableDeclaration(path) {
    const node = path.node;

    if (node.kind === 'let' || node.kind === 'const') {
      // 变量声明的kind, 可以是var let const
      // 然后第二个参数是声明的变量，let a, b, c这里的a, b, c就是node.declarations
      const varNode = t.variableDeclaration('var', node.declarations);
      path.replaceWith(varNode);
    }
  },
  Literal(path) {
    const node = path.node;
    if (node.value === 'hahaha') {
      node.value = 'hahahakakaka';
    }
  }
};
module.exports = function() {
  // 名称必须是visitor
  return { visitor };
};
